Sleep enough time for profiling file generated complete

This case using cmd “adb shell am profile stop android.server.am.debuggable” to stop profile.
Wait only 100ms for profile file to be generated.And then use cmd
"adb shell mv /data/local/tmp/profile.trace /storage/emulated/0/Android/data/android.server.cts.am/files/profile.trace"
to move profie.trace file to an accessible folder.

100ms is not enough time for profiling file generated complete.
So extend time to 300ms.

Bug: 112251130
Test: run the test case testAmStartStartProfilerNoSamplingNoStreaming pass.

Change-Id: I847d5860df354f9917dd4df91131bb36db24f07b
diff --git a/tests/framework/base/activitymanager/src/android/server/am/ActivityManagerAmProfileTests.java b/tests/framework/base/activitymanager/src/android/server/am/ActivityManagerAmProfileTests.java
index 6f2ec8d..eb6e62c 100644
--- a/tests/framework/base/activitymanager/src/android/server/am/ActivityManagerAmProfileTests.java
+++ b/tests/framework/base/activitymanager/src/android/server/am/ActivityManagerAmProfileTests.java
@@ -122,10 +122,11 @@
         launchActivity(DEBUGGABLE_APP_ACTIVITY);
 
         executeShellCommand(getStopProfileCmd(DEBUGGABLE_APP_ACTIVITY));
-        // Sleep for 0.1 second (100 milliseconds) so the generation of the profiling
+
+        // Sleep for 0.3 second (300 milliseconds) so the generation of the profiling
         // file is complete.
         try {
-            Thread.sleep(100);
+            Thread.sleep(300);
         } catch (InterruptedException e) {
             //ignored
         }